<?php

namespace FiloBlu\Job\Block;

use Exception;
use Magento\Directory\Block\Data;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Serialize\Serializer\Json;
use Magento\Framework\View\Element\Template;
use Magento\Store\Model\ScopeInterface;
use Psr\Log\LoggerInterface;
use Throwable;

/**
 * Class Form
 * @package FiloBlu\Job\Block
 */
class Form extends Template
{
    /**
     * Enabled config path
     */
    const CONFIG_DEPARTMENTS = 'filoblu_job_section/general/departments_enabled';
    /**
     * @var string
     */
    const ATTACHMENT_FIELD = 'attachment';
    /**
     * @var ScopeConfigInterface
     */
    public $scopeConfig;
    /**
     * @var Data
     */
    public $directoryBlock;
    /**
     * @var Json
     */
    public $serializer;
    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * Form constructor.
     * @param Template\Context $context
     * @param Data $directoryBlock
     * @param Json $jsonSerializer
     * @param LoggerInterface $logger
     * @param array $data
     */
    public function __construct(
        Template\Context $context,
        Data $directoryBlock,
        Json $jsonSerializer,
        LoggerInterface $logger,
        array $data = []
    )
    {
        parent::__construct($context, $data);
        $this->scopeConfig = $context->getScopeConfig();
        $this->directoryBlock = $directoryBlock;
        $this->serializer = $jsonSerializer;
        $this->logger = $logger;
    }

    /**
     * Returns action url for contact form
     * @return string
     */
    public function getFormAction()
    {
        return $this->getUrl('job/send/request', ['_secure' => true]);
    }

    /**
     * @return string
     */
    public function getAttachmentField()
    {
        return self::ATTACHMENT_FIELD;
    }

    /**
     * @return array
     */
    public function getDepartments()
    {
        $departmentsConfig =
            $this->scopeConfig->getValue(self::CONFIG_DEPARTMENTS, ScopeInterface::SCOPE_STORE);

        if ($departmentsConfig === null) {
            return [];
        }

        try {
            return $this->serializer->unserialize($departmentsConfig);
        } catch (Exception $exception) {
            $this->logger->error($exception->getMessage(), ['exception' => $exception]);
        } catch (Throwable $throwable) {
            $this->logger->error($throwable->getMessage(), ['exception' => $throwable]);
        }

        return [];
    }
}
