<?php

namespace FiloBlu\Job\Helper;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Area;
use Magento\Framework\DataObject;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Exception\MailException;
use Magento\Framework\Mail\Template\TransportBuilder;
use Magento\Store\Model\ScopeInterface;
use Magento\Store\Model\Store;

/**
 * Class Mailer
 * @package FiloBlu\Job\Helper
 */
class Mailer
{

    /**
     * Recipient email config path
     */
    const XML_PATH_EMAIL_RECIPIENT = 'filoblu_job_section/email/recipient_email';

    /**
     * Sender email config path
     */
    const XML_PATH_EMAIL_SENDER = 'filoblu_job_section/email/sender_email_identity';

    /**
     * Email template config path
     */
    const XML_PATH_EMAIL_TEMPLATE = 'filoblu_job_section/email/email_template';

    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;

    /**
     * @var TransportBuilder
     */
    protected $transportBuilder;

    /**
     * Mailer constructor.
     * @param ScopeConfigInterface $scopeConfig
     * @param TransportBuilder $transportBuilder
     */
    public function __construct(ScopeConfigInterface $scopeConfig, TransportBuilder $transportBuilder)
    {
        $this->scopeConfig = $scopeConfig;
        $this->transportBuilder = $transportBuilder;
    }

    /**
     * @param DataObject $templateVariables
     * @param string $replyTo
     * @param string $file
     * @param string $fileName
     * @throws LocalizedException
     * @throws MailException
     */
    public function sendMail($templateVariables, $replyTo, $file, $fileName)
    {
        $this->transportBuilder
            ->setTemplateIdentifier($this->scopeConfig->getValue(self::XML_PATH_EMAIL_TEMPLATE, ScopeInterface::SCOPE_STORE))
            ->setTemplateOptions(
                [
                    'area' => Area::AREA_FRONTEND,
                    'store' => Store::DEFAULT_STORE_ID,
                ]
            )
            ->setTemplateVars(['data' => $templateVariables])
            ->setFromByScope($this->scopeConfig->getValue(self::XML_PATH_EMAIL_SENDER))
            ->addTo($this->scopeConfig->getValue(self::XML_PATH_EMAIL_RECIPIENT))
            ->setReplyTo($replyTo)
            ->addAttachment($file, $fileName)
            ->getTransport()
            ->sendMessage();
    }
}
